@@ -17,20 +17,20 @@ class XCBuildConfiguration(PBXObject):
     "Debug" or "Release".
     """
 
-    base_configuration_reference: Optional[str]
+    base_configuration_reference_id: Optional[str]
     build_settings: Dict[str, Any]
     name: str
 
-    def base_configuration(self) -> Optional[XCBuildConfiguration]:
+    def base_configuration(self) -> Optional["XCBuildConfiguration"]:
         """Get the base configuration for this build configureation.
 
         :returns: The base configuration
         """
 
-        if not self.base_configuration_reference:
+        if not self.base_configuration_reference_id:
             return None
 
-        return cast(XCBuildConfiguration, self.objects()[self.base_configuration_reference])
+        return cast(XCBuildConfiguration, self.objects()[self.base_configuration_reference_id])
 
 
 @deserialize.key("build_configuration_ids", "buildConfigurations")
